@@ -4,10 +4,11 @@ from lazyTest.case import TestCase
 from lazyTest.base import  browser_Config
 from lazyTest.page import Page
 
-__version__ = '1.1.2'
+__version__ = '1.1.3'
 
+__author__ = 'buxiubuzhi'
 
-__description__ = ""
+__description__ = "WebUI自动化测试框架"
 
 __all__ = [
     "Sleep",
