@@ -1,5 +1,5 @@
 # -*- coding = UTF-8 -*-
-# Autohr   : yang
+# Author   :buxiubuzhi
 # File     : page.py
 # project  : McenterSystem
 # time     : 2020/12/3 11:56
@@ -18,7 +18,7 @@ class Page(object):
     def __init__(self, base_driver: browser_Config) -> None:
         self.base_driver = base_driver
         self.log = logging.getLogger(self.getClassName())
-        self.log.info("元素文件: -> %s" % (self.getProjectPath() + self.filePath + self.getClassName() + self.suffix))
+        self.log.info("元素文件: -> %s" % (self.getProjectPath() + self.filePath + self.__getClassName() + self.suffix))
         self.selector = readElementSource(
             self.getProjectPath() + self.filePath + self.getClassName() + self.suffix).readFileToDict()
 
